Learn R Programming

LWFBrook90R (version 0.6.3)

parms_to_rbrook90: Create parameter vectors for the LWF-Brook90 Fortran library

Description

Functions to create the param and siteparam vectors to be passed to the C-interface.

Usage

param_to_rlwfbrook90(b90f_input)

siteparam_to_rlwfbrook90(b90f_input)

Value

A numeric vector with the parameters in the required order.

Arguments

b90f_input

A named list of model parameters.