powered by
Creates a daily sequence for one year from parameters.
plant_b90( minval_before_incr, minval_after_decr = minval_before_incr, maxval, doy.incr, incr.dur, doy.decr, decr.dur, maxdoy )
A numeric vector of length maxdoy.
maxdoy
Minimum value used for the time period before doy.incr.
doy.incr
Minimum value used for time period after doy.decr.
doy.decr
Maximum value.
Day of year when increasing from minval_before_incr to maxval starts.
minval_before_incr
maxval
Duration (number of days) since doy.incr until maxval is reached.
Day of year when decreasing to minval_after_decr begins.
minval_after_decr
Duration (number of days) since doy.incr until minval_after_decr is reached.
Length of the year (366 for leap years).
plot(plant_b90(minval_before_incr = 0,minval_after_decr = 0.2, maxval=1, doy.incr = 121,incr.dur = 28, doy.decr = 280, decr.dur = 50, maxdoy = 365))
Run the code above in your browser using DataLab